function plotHistogram(histogram, scale, title) {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    ctx.globalAlpha = 1;

    // graph settings
    var padding = 20;
    var labelPadding = 5;
    var left = padding + 20;
    var top = padding;
    var right = canvas.width - padding;
    var bottom = canvas.height - padding;
    var barWidth = (right - left) / histogram.length;
    var maxHeight = 0.75 / scale * (bottom - top);

    // title
    ctx.fillStyle = "black";
    ctx.textAlign = "center"
    ctx.textBaseline = "top";
    ctx.fillText(title, (right + left) * 0.5, top);

    // draw axis
    ctx.beginPath();
    ctx.moveTo(left, top);
    ctx.lineTo(left, bottom);
    ctx.lineTo(right, bottom);
    ctx.stroke();

    // reference y guide
    var y = bottom - 0.75 * (bottom - top);

    ctx.strokeStyle = "#999999";
    ctx.beginPath();
    ctx.moveTo(left, y);
    ctx.lineTo(right, y);
    ctx.stroke();

    // reference y label
    ctx.textAlign = "right";
    ctx.textBaseline = "middle";
    ctx.fillText(scale.toPrecision(3), left - labelPadding, y);

    // x label    
    ctx.textAlign = "center";
    ctx.textBaseline = "top";
    for (var i in histogram)
        ctx.fillText(i, left + i * barWidth + barWidth * 0.5, bottom + labelPadding);

    // draw bars
    ctx.fillStyle = "#99CCFF";
    ctx.strokeStyle = "#000000";
    ctx.globalAlpha = 0.75;
    ctx.textAlign = "center";
    ctx.textBaseline = "bottom";

    for (var i in histogram) {
        var barHeight = histogram[i] * maxHeight;
        ctx.fillRect(left + i * barWidth, bottom - barHeight, barWidth, barHeight);
        ctx.strokeRect(left + i * barWidth, bottom - barHeight, barWidth, barHeight);
        ctx.fillText(histogram[i].toPrecision(3), left + i * barWidth + barWidth * 0.5, bottom - barHeight);
    }
}

function plotPdf(frequency, sampleCount, scale, title) {
    var pdf = frequency.slice();
    for (var i in pdf)
        pdf[i] /= sampleCount;
    plotHistogram(pdf, scale, title);
}

function plotCdf(frequency, sampleCount, title) {
    var pdf = frequency.slice();
    for (var i in pdf)
        pdf[i] /= sampleCount;

    var cdf = pdf2cdf(pdf);

    plotHistogram(cdf, 1, title);
}